@@ -18,16 +18,7 @@
 /* Written by Stuart Kemp, cpsrk@groper.jcu.edu.au.
    Modified by David MacKenzie, djm@gnu.ai.mit.edu. */
 
-#ifdef HAVE_CONFIG_H
-#if defined (CONFIG_BROKETS)
-/* We use <config.h> instead of "config.h" so that a compilation
-   using -I. -I$srcdir will use ./config.h rather than $srcdir/config.h
-   (which it would do because it found this file in $srcdir).  */
 #include <config.h>
-#else
-#include "config.h"
-#endif
-#endif
 
 #include <stdio.h>
 #include <getopt.h>
@@ -51,11 +42,8 @@ char *realloc ();
 #define MAX(a,b) (((a) > (b)) ? (a) : (b))
 #endif
 
-#ifndef INT_MAX
-#define INT_MAX (~(1 << (sizeof (int) * 8 - 1)))
-#endif /* INT_MAX */
-
 void error ();
+int safe_read ();
 
 
 static char *xrealloc ();
@@ -87,6 +75,7 @@ struct control
   int offset;			/* Offset from regexp to split at. */
   int lines_required;		/* Number of lines required. */
   int repeat;			/* Repeat count. */
+  int repeat_forever;		/* Non-zero if `*' used as a repeat count. */
   int argnum;			/* ARGV index. */
   boolean ignore;		/* If true, produce no output (for regexp). */
 };
@@ -235,7 +224,7 @@ static struct option const longopts[] =
   {"keep-files", no_argument, NULL, 'k'},
   {"elide-empty-files", no_argument, NULL, 'z'},
   {"prefix", required_argument, NULL, 'f'},
-  {"suffix", required_argument, NULL, 'b'},
+  {"suffix-format", required_argument, NULL, 'b'},
   {"help", no_argument, &show_help, 1},
   {"version", no_argument, &show_version, 1},
   {NULL, 0, NULL, 0}
@@ -314,7 +303,7 @@ read_input (dest, max)
   if (max == 0)
     return 0;
 
-  bytes_read = read (input_desc, dest, max);
+  bytes_read = safe_read (input_desc, dest, max);
 
   if (bytes_read == 0)
     have_read_eof = TRUE;
@@ -608,7 +597,7 @@ load_buffer ()
       b->bytes_used += (unsigned) read_input (p, bytes_avail);
 
       lines_found = record_line_starts (b);
-      bytes_wanted = b->bytes_alloc + INCR_SIZE;
+      bytes_wanted = b->bytes_alloc * 2;
       if (!lines_found)
 	free_buffer (b);
     }
@@ -822,7 +811,7 @@ process_line_count (p, repetition)
   /* Check for requesting a line that has already been written out.
      If this ever happens, it's due to a bug in csplit. */
   if (linenum >= last_line_to_save)
-    handle_line_error (p, repetition);
+    abort ();
 
   while (linenum++ < last_line_to_save)
     {
@@ -890,7 +879,7 @@ process_regexp (p, repetition)
 	  line = find_line (++current_line);
 	  if (line == NULL)
 	    {
-	      if (p->repeat == INT_MAX)
+	      if (p->repeat_forever)
 		{
 		  if (!ignore)
 		    {
@@ -930,7 +919,7 @@ process_regexp (p, repetition)
 	  line = find_line (++current_line);
 	  if (line == NULL)
 	    {
-	      if (p->repeat == INT_MAX)
+	      if (p->repeat_forever)
 		{
 		  if (!ignore)
 		    {
@@ -979,12 +968,14 @@ split_file ()
     {
       if (controls[i].regexpr)
 	{
-	  for (j = 0; j <= controls[i].repeat; j++)
+	  for (j = 0; (controls[i].repeat_forever
+		       || j <= controls[i].repeat); j++)
 	    process_regexp (&controls[i], j);
 	}
       else
 	{
-	  for (j = 0; j <= controls[i].repeat; j++)
+	  for (j = 0; (controls[i].repeat_forever
+		       || j <= controls[i].repeat); j++)
 	    process_line_count (&controls[i], j);
 	}
     }
@@ -1115,6 +1106,7 @@ new_control_record ()
   p = &controls[control_used++];
   p->regexpr = NULL;
   p->repeat = 0;
+  p->repeat_forever = 0;
   p->lines_required = 0;
   p->offset = 0;
   return p;
@@ -1186,7 +1178,7 @@ parse_repeat_count (argnum, p, str)
   *end = '\0';
 
   if (str+1 == end-1 && *(str+1) == '*')
-    p->repeat = INT_MAX;
+    p->repeat_forever = 1;
   else
     if (!string_to_number (&p->repeat, str +  1))
       error (1, 0, "%s}: integer required between `{' and `}'",
@@ -1528,7 +1520,7 @@ main (argc, argv)
 
   if (show_version)
     {
-      printf ("%s\n", version_string);
+      printf ("csplit - %s\n", version_string);
       exit (0);
     }
 
@@ -1573,8 +1565,8 @@ Usage: %s [OPTION]... FILE PATTERN...\n\
 	      program_name);
       printf ("\
 \n\
-  -b, --suffix=FORMAT        use sprintf FORMAT instead of %%d\n\
-  -f, --prefix=PREFIX        use PREFIX instead of xx\n\
+  -b, --suffix-format=FORMAT use sprintf FORMAT instead of %%d\n\
+  -f, --prefix=PREFIX        use PREFIX instead of `xx'\n\
   -k, --keep-files           do not remove output files on errors\n\
   -n, --digits=DIGITS        use specified number of digits instead of 2\n\
   -s, --quiet, --silent      do not print counts of output file sizes\n\
@@ -1590,7 +1582,7 @@ Read standard input if FILE is -.  Each PATTERN may be:\n\
   {INTEGER}          repeat the previous pattern specified number of times\n\
   {*}                repeat the previous pattern as many times as possible\n\
 \n\
-A line OFFSET is a `+' or `-' (required) followed by a positive integer.\n\
+A line OFFSET is a required `+' or `-' followed by a positive integer.\n\
 ");
     }
   exit (status);
